import Glyphicon from 'atoms/Glyphicon';
import LabelText from 'atoms/LabelText';
import useDrupalTranslation from 'hooks/drupal_translation';
import EntityData from 'model/EntityData';
import EntityInfoTemplate from 'model/EntityInfoTemplate';
import { Form } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import { getOperationsImpl } from 'service/convert';
import { cspToLabel, entityNameToLabel } from 'service/string';

const DetailActionButtonGroup = ({detailTemplate, cloudContext, entityData, entityId}: {
  detailTemplate: EntityInfoTemplate,
  cloudContext: string,
  entityData?: EntityData,
  entityId: string
}) => {

  const { t } = useDrupalTranslation();

  const operations = entityData
    ? getOperationsImpl(detailTemplate.cloudServiceProvider + '_' + detailTemplate.entityName, entityData.attributes)
      .map((label) => {
        return {
          action: label.toLowerCase().replaceAll(' ', '_'),
          label,
        };
      })
    : [];

  const operationActions = [
    { action: 'edit', label: 'Edit' },
    ...operations,
    { action: 'delete', label: 'Delete' },
  ];

  return <Form.Group className="mb-4">
    <Link className="btn btn-primary" to={`/${detailTemplate.cloudServiceProvider}/${cloudContext}/${detailTemplate.entityName}`}>
      <Glyphicon type="th-list" />
      {
        Drupal.t('List @cloudServiceProvider @entityName', {
          '@cloudServiceProvider': cspToLabel(detailTemplate.cloudServiceProvider),
          '@entityName': entityNameToLabel(detailTemplate.entityName),
        })
      }
    </Link>
    {
      entityData
      ? operationActions.map((record) => {
          const to = `/${detailTemplate.cloudServiceProvider}/${cloudContext}/${detailTemplate.entityName}/${entityId}/${record.action}`;
          const buttonColor = record.action !== 'delete'
            ? 'primary' : 'danger';

          return <Link className={`btn btn-${buttonColor}`} key={record.action} to={to}>
            <LabelText text={record.label} />
          </Link>;
        })
      : <></>
    }
  </Form.Group>;

}

export default DetailActionButtonGroup;
